@@ -42,7 +42,7 @@ def main():
     #monroe-----------------------------------------
     parser_monroe = subparsers.add_parser('monroe', help='Consensus assembly for SARS-CoV-2 from ARTIC + Illumina protocols.', add_help=False)
     monroe_subparsers = parser_monroe.add_subparsers(title='monroe_commands',metavar='',dest='monroe_command')
-    parser_monroe.add_argument('--get_config',type=str,choices=["pe_assembly", "ont_assembly", "cluster_analysis"],help="Get a Nextflow configuration template for the chosen workflow.")
+    parser_monroe.add_argument('--get_config',type=str,choices=["pe_assembly", "se_assembly", "clearlabs_assembly", "ont_assembly", "cluster_analysis"],help="Get a Nextflow configuration template for the chosen workflow.")
 
     ##monroe_pe_assembly----------------------------
     subparser_monroe_pe_assembly = monroe_subparsers.add_parser('pe_assembly',help='Assembly SARS-CoV-2 genomes from paired-end read data generated from ARTIC amplicons', add_help=False)
@@ -53,6 +53,23 @@ def main():
     subparser_monroe_pe_assembly.add_argument('--resume', default="", action="store_const",const="-resume",help="resume a previous run")
     subparser_monroe_pe_assembly.add_argument('--config','-c', type=str,help="Nextflow custom configuration.")
 
+    ##monroe_se_assembly----------------------------
+    subparser_monroe_se_assembly = monroe_subparsers.add_parser('se_assembly',help='Assembly SARS-CoV-2 genomes from single-end read data generated from ARTIC amplicons', add_help=False)
+    subparser_monroe_se_assembly.add_argument('reads_path', type=str,help="path to the location of the single-end reads in a fastq format")
+    subparser_monroe_se_assembly.add_argument('--primers', type=str, choices=["V1","V2","V3"], help="indicate which ARTIC primers were used (V1, V2, or V3)")
+    subparser_monroe_se_assembly.add_argument('--profile', type=str,choices=["docker", "singularity"],help="Nextflow profile. Default will try docker first, then singularity if the docker executable cannot be found.")
+    subparser_monroe_se_assembly.add_argument('--output','-o',metavar="<output_path>",type=str,help="Path to ouput directory, default \"monroe_results\".",default="monroe_results")
+    subparser_monroe_se_assembly.add_argument('--resume', default="", action="store_const",const="-resume",help="resume a previous run")
+    subparser_monroe_se_assembly.add_argument('--config','-c', type=str,help="Nextflow custom configuration.")
+
+    ##monroe_clearlabs_assembly----------------------------
+    subparser_monroe_clearlabs_assembly = monroe_subparsers.add_parser('clearlabs_assembly',help='Assembly SARS-CoV-2 genomes from Clear Labs ont read data', add_help=False)
+    subparser_monroe_clearlabs_assembly.add_argument('reads_path', type=str,help="path to the location of the clearlabs reads in a fastq format")
+    subparser_monroe_clearlabs_assembly.add_argument('--profile', type=str,choices=["docker", "singularity"],help="Nextflow profile. Default will try docker first, then singularity if the docker executable cannot be found.")
+    subparser_monroe_clearlabs_assembly.add_argument('--output','-o',metavar="<output_path>",type=str,help="Path to ouput directory, default \"monroe_results\".",default="monroe_results")
+    subparser_monroe_clearlabs_assembly.add_argument('--resume', default="", action="store_const",const="-resume",help="resume a previous run")
+    subparser_monroe_clearlabs_assembly.add_argument('--config','-c', type=str,help="Nextflow custom configuration.")
+
     ##monroe_ont_assembly----------------------------
     ##medaka nanopolish
     subparser_monroe_ont_assembly = monroe_subparsers.add_parser('ont_assembly',help='Assembly SARS-CoV-2 genomes from ONT read data generated from ARTIC amplicons', add_help=False)
@@ -135,6 +152,16 @@ def main():
     parser_cutshaw.add_argument('--get_config',action="store_true",help="Get a Nextflow configuration template for cutshaw.")
     parser_cutshaw.add_argument('--resume', default="", action="store_const",const="-resume",help="resume a previous run")
 
+    #cecret-----------------------------------------
+    parser_cecret = subparsers.add_parser('cecret', help='Consensus fasta creation of amplicon-based SARS-CoV-2 Illumina sequencing.', add_help=False)
+    parser_cecret.add_argument('reads_path', type=str,help="path to the location of reads in a fastq format",nargs='?', default=False)
+    parser_cecret.add_argument('--reads_type',type=str,choices=["paired","single"],help="Specify either \"paired\"-end or \"single\"-end reads, default \"paired\".",default="paired")
+    parser_cecret.add_argument('--output','-o',metavar="<output_path>",type=str,help="Path to ouput directory, default \"cecret\".",default="cecret")
+    parser_cecret.add_argument('--profile', type=str,choices=["docker","singularity"],help="Nextflow profile. Default will try docker first, then singularity if the docker executable cannot be found.")
+    parser_cecret.add_argument('--config','-c', type=str,help="Nextflow custom configuration.")
+    parser_cecret.add_argument('--get_config',action="store_true",help="Get a Nextflow configuration template for cecret.")
+    parser_cecret.add_argument('--resume', default="", action="store_const",const="-resume",help="resume a previous run")
+
     #----------------------------------------------
     args = parser.parse_args()
 
@@ -231,6 +258,16 @@ def main():
             dest_path = os.path.join(os.getcwd(),date.today().strftime("%y-%m-%d")+"_pe_assembly.config")
             copyfile(config_path,dest_path)
             sys.exit()
+        elif args.get_config == "se_assembly":
+            config_path = os.path.join(monroe_path,"configs/se_user_config.config")
+            dest_path = os.path.join(os.getcwd(),date.today().strftime("%y-%m-%d")+"_se_assembly.config")
+            copyfile(config_path,dest_path)
+            sys.exit()
+        elif args.get_config == "clearlabs_assembly":
+            config_path = os.path.join(monroe_path,"configs/clearlabs_user_config.config")
+            dest_path = os.path.join(os.getcwd(),date.today().strftime("%y-%m-%d")+"_clearlabs_assembly.config")
+            copyfile(config_path,dest_path)
+            sys.exit()
         elif args.get_config == "ont_assembly":
             config_path = os.path.join(monroe_path,"configs/ont_user_config.config")
             dest_path = os.path.join(os.getcwd(),date.today().strftime("%y-%m-%d")+"_ont_assembly.config")
@@ -267,8 +304,8 @@ def main():
             if not args.config and not args.primers:
                 raise Exception(f"argument --primers: no primer set selected, choose from ('V1', 'V2', 'V3') or use a custom configuration.")
             if not args.config:
-                primer_path = f"/reference/ARTIC-{args.primers}.bed"
-                profile = profile + f" --primerPath {primer_path}"
+                primer_set = f"/configs/artic_{args.primers}_nCoV-2019.bed"
+                profile = profile + f" --primerSet {primer_set}"
             #build command
             command = nextflow_path + f" {config} run {monroe_path}/monroe_pe_assembly.nf {profile} {args.resume} --pipe pe --reads {args.reads_path} --outdir {args.output} -with-trace {args.output}/logs/{exec_time}Monroe_trace.txt -with-report {args.output}/logs/{exec_time}Monroe_execution_report.html {work}"
             #run command using nextflow in a subprocess
@@ -276,6 +313,27 @@ def main():
             child = pexpect.spawn(command)
             child.interact()
 
+        if args.monroe_command == 'se_assembly':
+            #check for either standard ARTIC primer version, or a custom config
+            if not args.config and not args.primers:
+                raise Exception(f"argument --primers: no primer set selected, choose from ('V1', 'V2', 'V3') or use a custom configuration.")
+            if not args.config:
+                primer_set = f"/configs/artic_{args.primers}_nCoV-2019.bed"
+                profile = profile + f" --primerSet {primer_set}"
+            #build command
+            command = nextflow_path + f" {config} run {monroe_path}/monroe_se_assembly.nf {profile} {args.resume} --pipe pe --reads {args.reads_path} --outdir {args.output} -with-trace {args.output}/logs/{exec_time}Monroe_trace.txt -with-report {args.output}/logs/{exec_time}Monroe_execution_report.html {work}"
+            #run command using nextflow in a subprocess
+            print("Starting the Monroe single-end assembly:")
+            child = pexpect.spawn(command)
+            child.interact()
+
+        if args.monroe_command == 'clearlabs_assembly':
+            #build command
+            command = nextflow_path + f" {config} run {monroe_path}/monroe_clearlabs_assembly.nf {profile} {args.resume} --pipe clearlabs --reads {args.reads_path} --outdir {args.output} -with-trace {args.output}/logs/{exec_time}Monroe_trace.txt -with-report {args.output}/logs/{exec_time}Monroe_execution_report.html {work}"
+            #run command using nextflow in a subprocess
+            print("Starting the Monroe Clear Labs assembly:")
+            child = pexpect.spawn(command)
+            child.interact()
 
         if args.monroe_command == 'cluster_analysis':
             #give report template to user if requested
@@ -586,3 +644,58 @@ def main():
         print("Starting the Cutshaw pipeline:")
         child = pexpect.spawn(command)
         child.interact()
+
+    #cecret--------------------------------
+
+    if program == 'cecret':
+        #cecret path
+        cecret_path = os.path.join(workflows_path,"cecret/")
+
+        #give config to user if requested
+        if args.get_config:
+            config_path = os.path.join(cecret_path,"configs/cecret_config_template.config")
+            dest_path = os.path.join(os.getcwd(),date.today().strftime("%y-%m-%d")+"_cecret.config")
+            copyfile(config_path,dest_path)
+            sys.exit()
+
+        #check for reads_path
+        if not args.reads_path:
+            parser_cecret.print_help()
+            print("Please specify a path to a directory containing paired end raw reads.")
+            print("Note: Can specify an empty directory if single reads parameter is set.")
+            sys.exit()
+
+        #check for config or profile
+        config = ""
+        if args.config:
+            config = "-C " + os.path.abspath(args.config)
+            profile = ""
+        elif args.profile:
+            profile = f"-profile {args.profile}"
+        elif not profile:
+            print('Singularity or Docker is not installed or not in found in PATH.')
+            sys.exit(1)
+
+        reads_type = ""
+        if args.reads_type == "paired":
+            reads_type = "--reads"
+        elif args.reads_type == "single":
+            reads_type = "--single_reads"
+        elif not args.reads_type:
+            print("Type of reads not specified for some reason")
+            sys.exit(1)
+
+        #set work dir into local logs dir if profile not aws
+        work = ""
+        if profile and not args.config:
+            work = f"-w {args.output}/logs/work"
+
+        #build command
+        command = nextflow_path
+        command = command + f" {config} run {cecret_path}/cecret.nf {profile} {args.resume} {reads_type} {args.reads_path} --outdir {args.output} -with-trace {args.output}/logs/{exec_time}cecret_trace.txt -with-report {args.output}/logs/{exec_time}cecret_execution_report.html {work}"
+        print(command)
+
+        #run command using nextflow in a subprocess
+        print("Starting the cecret workflow:")
+        child = pexpect.spawn(command)
+        child.interact()
